Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Output ¶
type Output struct {
Timeout time.Duration
StacktraceConfiguration StackTraceConfiguration
FieldsToTag []string
// contains filtered or unexported fields
}
Output is a xlog to sentry output
func NewSentryOutput ¶
type StackTraceConfiguration ¶
type StackTraceConfiguration struct {
// whether stacktraces should be enabled
Enable bool
// the level at which to start capturing stacktraces
Level xlog.Level
// how many stack frames to skip before stacktrace starts recording
Skip int
// the number of lines to include around a stack frame for context
Context int
// the prefixes that will be matched against the stack frame.
// if the stack frame's package matches one of these prefixes
// sentry will identify the stack frame as "in_app"
InAppPrefixes []string
}
StackTraceConfiguration allows for configuring stacktraces
Click to show internal directories.
Click to hide internal directories.